@@ -139,14 +139,13 @@ NULL
 #' 
 #' @name rgexf-package
 #' @aliases rgexf-package rgexf gephi
-#' @docType package
 #' @note See the GEXF primer for details on the GEXF graph format:
-#' \url{https://gephi.org/gexf/1.2draft/gexf-12draft-primer.pdf}
+#' \url{http://gexf.net/1.2draft/gexf-12draft-primer.pdf}
 #' @references \itemize{ \item rgexf project site:
 #' \url{https://github.com/gvegayon/rgexf} \item Gephi project site:
-#' \url{https://gephi.org/} \item GEXF project site: \url{https://gephi.org/gexf/format//}
+#' \url{https://gephi.org/} \item GEXF project site: \url{https://gexf.net/}
 #' \item gexf-js project website: \url{https://github.com/raphv/gexf-js} 
-#' \item Sigmasj project site: \url{http://sigmajs.org/}
+#' \item Sigmasj project site: \url{https://www.sigmajs.org/}
 #' }
 #' @keywords package
 #' @examples
@@ -165,7 +164,7 @@ NULL
 #'     demo(gexfrandom) # A nice routine creating a good looking graph
 #' }
 #' 
-NULL
+"_PACKAGE"
 
 
 
